@@ -82,7 +82,7 @@ class Mt3dSsm(Package):
             for i,a in enumerate(criv):
                 #b = np.empty((mfriv.layer_row_column_Q[0].shape[0]))                
                 #self.assignarray_old(b , a )                
-                b = util_2d(model,(mfriv.layer_row_column_Q[0].shape[0],),np.float32,a,name='ssm_riv_'+str(i+1))
+                b = util_2d(model,(mfriv.layer_row_column_data[0].shape[0],),np.float32,a,name='ssm_riv_'+str(i+1))
                 self.criv = self.criv + [b]                        
                
         #RCH
@@ -180,7 +180,7 @@ class Mt3dSsm(Package):
         mfriv = self.parent.mf.get_package('RIV')
         mfwel = self.parent.mf.get_package('WEL')  
         # Open file for writing
-        f_ssm = open(self.file_name[0], 'w')
+        f_ssm = open(self.fn_path, 'w')
         maxssm = 0
         if (mfwel == None):
             f_ssm.write('%2s' % ('F'))
